@@ -4,6 +4,8 @@ use 5.008;
 use strict;
 use warnings;
 
+use Lingua::PT::Words2Nums;
+
 require Exporter;
 
 our @ISA = qw(Exporter);
@@ -18,7 +20,7 @@ our @EXPORT = qw(
 	ord2num isord
 );
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 my %values;
 
@@ -36,7 +38,18 @@ Lingua::PT::Ords2Nums - Converts Portuguese ordinals to numbers
 
 BEGIN {
   %values = (
+    'bilionsimo'	=> 1000000000,
+    'milionsimo'	=> 1000000,
+    'milsimo'		=> 1000,
 
+    'nongentsimo'	=> 900,
+    'octigentsimo'	=> 800,
+    'septigentsimo'	=> 700,
+    'seiscentsimo'	=> 600,
+    'quingentsimo'	=> 500,
+    'quadrigentsimo'	=> 400,
+    'tricentsimo'	=> 300,
+    'ducentsimo'	=> 200,
     'centsimo' 	=> 100,
 
     'nonagsimo'	=> 90,
@@ -66,6 +79,10 @@ sub ord2num {
   $_ = shift || return undef;
   my $result = 0;
 
+  s/(.*)bilionsimos/$result += (word2num($1) * 1000000000)/e;
+  s/(.*)milionsimos/$result += (word2num($1) * 1000000)/e;
+  s/(.*)milsimos/$result += (word2num($1) * 1000)/e;
+
   for my $value (keys %values) {
     s/$value/$result += $values{$value}/e;
   }
@@ -80,7 +97,14 @@ __END__
 
 =head1 DESCRIPTION
 
-Converts Portuguese ordinals to numbers. Works up to 199.
+Converts Portuguese ordinals to numbers. Works up to 999.999.999.999
+('novecentos e noventa e nove bilionsimos novecentos e noventa e nove
+milionsimos novecentos e noventa e nove milsimos nongentsimo nonagsimo
+nono').
+
+=head1 DEPENDENCIES
+
+Lingua::PT::Words2Nums
 
 =head1 SEE ALSO
 
